@@ -327,16 +327,40 @@ def center_by_columns(mat):
 
 
 def normalize_by_columns(mat: Union[np.ndarray, pd.DataFrame],
-                         make_positive: bool = True, add_cst=None, mult_cst=None):
+                         make_positive: bool = True,
+                         add_cst: Union[None, np.ndarray, pd.DataFrame] = None,
+                         mult_cst: Union[None, np.ndarray, pd.DataFrame] = None):
+    """
+    normalize_by_columns: applies linear transformation to a matrix mat
+    mat <- (mat - additive_constant_vector) / multiplicative_constant_vector
+    The operations are done columnwise
+    Parameters
+    ----------
+    mat: Union[np.ndarray, pd.DataFrame]: the matrix to normalize
+    make_positive: bool
+        if true, the constant vector is the minimum by columns
+        if false, the mean by colums unless the parameter add_cst is not None
+    add_cst:
+        a forced additive constant. If none, the mean columnwise.
+    mult_cst:
+        a forced multiplicative constant. If None, the stdev columnwise.
+
+    Returns
+    -------
+    The normalized matrix
+    The additive constant effectively used
+    The multiplicative constant effectively used
+    """
     if type(mat) is not pd.DataFrame:
         cols = list(["F" + str(x) for x in range(1, mat.shape[1] + 1)])
         mat = pd.DataFrame(data=mat, columns=cols)
     normalized_mat = mat.copy()
-    add_constants = np.nanmin(normalized_mat, axis=0) if make_positive else \
+    take_min = make_positive and (add_cst is None)
+    add_constants = np.nanmin(normalized_mat, axis=0) if take_min else \
         add_cst if (add_cst is not None) else np.nanmean(normalized_mat, axis=0)
     mult_constants = mult_cst if (mult_cst is not None) else np.nanstd(normalized_mat, axis=0)
-    normalized_mat -= add_constants
-    normalized_mat /= mult_constants
+    normalized_mat = np.subtract(normalized_mat, add_constants.T)
+    normalized_mat = np.divide(normalized_mat, mult_constants.T)
 
     return normalized_mat, add_constants, mult_constants
 
