@@ -67,12 +67,12 @@ if __name__ == "__main__":
         w_avg = int(w_size / nb_w_clusters)
         # wclust_factor = np.random.uniform(0.0, wclust_f)
 
+        # noinspection PyTupleAssignmentBalance
         generated_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
-                                                               h_icorr_min=icorrmin, h_icorr_max=xcorrmax,
-                                                               w_icorr_min=xcorrmin, w_icorr_max=icorrmax,
-                                                               random_norms=rand_norms, epsilon=eps,
-                                                               avg_h_clust=h_avg,
-                                                               avg_w_clust=w_avg)
+                                                               h_icorr_min=icorrmin, h_xcorr_max=xcorrmax,
+                                                               w_icorr_min=xcorrmin, w_xcorr_max=icorrmax,
+                                                               random_norms=rand_norms, epsilon=eps, avg_w_clust=w_avg,
+                                                               avg_h_clust=h_avg)
         rnstr = "RandNorms" if rand_norms else "ConstNorms"
 
         df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax, known_ncomp=nb_clusters,
