@@ -78,7 +78,7 @@ if __name__ == "__main__":
         ncmax = np.max(norm_train_data.index)-1
         train_synthegram = my_k_estimator.estimate_ncomp(df_mini_screeplots=norm_train_data, ncmin=ncmin, ncmax=ncmax)
 
-    est_do_swimmer = True
+    est_do_swimmer = False
     if est_do_swimmer:
         swimmer_file = "swimmer.xlsx"
         swimmer_data = pd.read_excel(str(data_path.path) + "/" + swimmer_file)
@@ -101,7 +101,7 @@ if __name__ == "__main__":
         sw_preds.to_csv(str(res_path) + "/swimmer_preds.csv")
         sw_mini_screeplots.to_csv(str(res_path) + "/swimmer_mini_screeplots.csv")
 
-    est_do_sausage = True
+    est_do_sausage = False
     if est_do_sausage:
         sausage_file = "Sausage Raw NIR.xlsx"
         sausage_data = pd.read_excel(str(data_path.path) + "/" + sausage_file)
@@ -123,6 +123,28 @@ if __name__ == "__main__":
         sa_preds.to_csv(str(res_path) + "/sausage_preds.csv")
         sa_mini_screeplots.to_csv(str(res_path) + "/sausage_mini_screeplots.csv")
 
+    est_do_brunet = True
+    if est_do_brunet:
+        brunet_file = "ALL-AML Brunet-norm.csv"
+        brunet_data = pd.read_csv(str(data_path.path) + "/" + brunet_file, index_col=0)
+        brunet_data = brunet_data.iloc[:, 1:]
+        # brunet_screeplot = nmf.generate_scree_plot(brunet_data, ncmin=2, ncmax=30)
+        recalc_brunet = True
+        ncmin = 2
+        ncmax = 25
+        if recalc_brunet:
+            br_synthegram, br_preds, br_mini_screeplots = my_k_estimator.estimate_ncomp(mat=brunet_data,
+                                                                                        ncmin=ncmin, ncmax=ncmax)
+            pass
+        else:
+            br_mini_screeplots = pd.read_csv(str(res_path) + "/brunet_mini_screeplots.csv", index_col=0)
+            br_synthegram, br_preds, _ = \
+                my_k_estimator.estimate_ncomp(df_mini_screeplots=br_mini_screeplots,
+                                              ncmin=ncmin, ncmax=ncmax)
+        br_synthegram.to_csv(str(res_path) + "/brunet_synthegram.csv")
+        br_preds.to_csv(str(res_path) + "/brunet_preds.csv")
+        br_mini_screeplots.to_csv(str(res_path) + "/brunet_mini_screeplots.csv")
+
         pass
 
 
